# Caer, in modules

`caer` contains functions to simplify common tasks used when developing and evaluating computer vision systems. A short description of the sub-modules is provided below. For more details about what functions are available and how to use them, please review the doc-strings provided with the code.

## Sub-modules

### [data](data)
Test images and example data.

### [path](path)
OS-specific Path Manipulations

### [preprocessing](preprocessing)
Image preprocessing utilities

### [video](video)
Video processing utilities